---
slug: /introduction/installation
sidebar_position: 10
---

# Installation & Setup

Therix is available to install via pypi.org for use in any python project. 
If you need a custom solution get in touch at [enterprise@therix.ai](mailto:enterprise@therix.ai)


## Installation

TODO: add details of pypi package. 


## Setup 

TBD

### Python Versions Supported

TBD

### ENV Vars with meaning

TBD

### Optional ENV VARS

Cache, etc